use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( examples lib script t xt ) );
__DATA__
Alders
Andrew
Book
Chris
Dan
Etheridge
Florian
Karen
Kelly
Kensho
Lapworth
Leir
Leo
Nehren
Olaf
Prather
Rachel
Ragwitz
Rick
Shawn
Sorichetti
Task
Whatson
apeiron
chris
ether
grinnz
irc
leo
lib
olaf
rafl
rkellyalso
rleir
shawn
whatson
